@@ -79,7 +79,7 @@ public final class OXAutoCIDMySQLStorage extends OXAutoCIDSQLStorage {
     public int generateContextId() throws StorageException {
         final Connection con;
         try {
-            con = cache.getConnectionForConfigDB();
+            con = cache.getWriteConnectionForConfigDB();
         } catch (final PoolException e) {
             log.error("", e);
             throw new StorageException(e.getMessage());
@@ -98,7 +98,7 @@ public final class OXAutoCIDMySQLStorage extends OXAutoCIDSQLStorage {
             if (rollback) {
                 doRollback(con);
             }
-            cache.closeConfigDBSqlStuff(con, null);
+            cache.closeWriteConfigDBSqlStuff(con, null);
         }
     }
 
